/**
 * @author 无愚
 * @description 数据集接口模型
 */
import { DsCreateOriginEnum, DsType } from './data-source';
/** 关联字段 */
export declare type JoinKey = {
    /** 源表关联物理字段名 */
    sourceKey: string;
    /** 源表关联物理字段类型(QBI目前没在用，保留) */
    sourceType?: string;
    /** 目标表关联物理字段名 */
    targetKey: string;
    /** 标表关联物理字段类型(QBI目前没在用，保留) */
    targetType?: string;
    /** 条件（目前QBI只支持这个equal-to） */
    condition: JoinCondition;
};
/** 表模型 */
export interface PhysicalTable {
    /** 唯一标识 */
    uniqueId: string;
    /** 表展示名称 */
    caption?: string;
    /** 表id */
    tableName: string;
    /** 物理表所属数据源ID */
    datasourceId: string;
    /** 是否为事实表（中心表标识） */
    factTable: boolean;
    dsType: DsType;
}
/** 表模型 */
export interface VirtualTable {
    /** 唯一标识 */
    uniqueId: string;
    /** 表展示名称 */
    caption: string;
    /** 表名 */
    tableName: string;
    /** 物理表所属数据源ID */
    datasourceId: string;
    /** 是否为事实表（中心表标识） */
    factTable: boolean;
    dsType: DsType;
    sqlId: string;
    sql: string;
}
export interface PhysicalLink {
    /** 源表id */
    source: string;
    /** 关联表id */
    target: string;
    /** 关联类型 */
    joinType: TableJoinType;
    /** 目前只有many-to-one */
    relation: TableRelation;
    joinKeys: JoinKey[];
}
export declare class PhysicalSchema {
    tables: PhysicalTable[];
    /** 自定义sql、view */
    virtualTables: VirtualTable[];
    /** 表关联关系 */
    links: PhysicalLink[];
    /** odps表是否开启全表扫描 */
    sqlHintTypes?: string[];
}
/** 数据集层级结构/文件夹/属性的嵌套关系 */
export declare type FieldTree = AttributeNode | FolderAndHierarchyNode;
/** 数据集逻辑模型 */
export declare class CubeSchema {
    /** 唯一标识，无业务逻辑，不要使用 */
    uniqueId: string;
    /** 数据集ID */
    cubeId: string;
    /** 数据源ID */
    datasourceId: string;
    /** 数据集名称 */
    caption: string;
    /** 字段列表 */
    fields: Field[];
    /** 普通字段、层系、文件夹树形结构 */
    fieldTree: FieldTree[];
    /** 过滤条件 */
    filter?: FilterAttr;
    /** 全局参数 */
    params: ParamType[];
    /** 占位符 */
    sqlPlaceholders: ParamType[];
}
/** 数据集额外信息 */
export declare class SchemaExtraInfo {
    /** 数据集所在工作空间的文件夹位置 */
    aimDirId: string;
    hasAuthorizedUse?: boolean;
    /** 权限列表 */
    permissionList?: string[];
    /** 行级权限，列级权限字段id */
    dataLevelAttributeIds: string[];
    /** 无列级权限的字段 */
    withoutColumnLevelPermissionFields: string[];
    /** 聚合方式 */
    aggFunctions?: string[];
    /** 是否开启数据脱敏 */
    isDataMaskOpen?: number;
    /** 是否开启列级权限 1=开启 0=未开启 */
    isOpenColumnLevelPermission?: number;
    /** 是否开启了行级权限 1=开启 0=未开启 */
    isOpenRowLevelPermission?: number;
    /** 是否生成了影子数据集 */
    hasShadowCube: boolean;
    /** 当前数据集来自的类型 */
    dsCreateOrigin?: DsCreateOriginEnum;
}
/** 数据集模型 */
export declare class CubeModel {
    /** 物理表 */
    physicalSchema: PhysicalSchema;
    /** 数据集逻辑模型 */
    cubeSchema: CubeSchema;
    /** 数据集结构版本 */
    metaModelVersion: string;
    /** 数据集额外信息 */
    schemaExtraInfo: SchemaExtraInfo;
}
/** 表关联类型 */
export declare enum TableJoinType {
    LEFT_OUTER_JOIN = "LEFT_OUTER_JOIN",
    INNER_JOIN = "INNER_JOIN",
    FULL_OUTER_JOIN = "FULL_OUTER_JOIN",
    JOIN_ERROR = "JOIN_ERROR"
}
export declare enum TableRelation {
    MANY_TO_ONE = "many-to-one"
}
export declare enum JoinCondition {
    EQUAL_TO = "equal-to",
    UNEQUAL_TO = "unequal-to",
    GREATER_THAN = "greater-than",
    LESS_THAN = "less-than"
}
/** 字段列表定义，包含维度、度量 */
export interface Field {
    /** 唯一标识 */
    uniqueId: string;
    /** 字段名称 */
    caption: string;
    type: 'Dimension' | 'Measure';
    /** 标记数据面板上的字段、文件夹，和数据集原有的字段、文件夹区别开来 */
    fromPanel?: boolean;
    /** 老接口保留字段（计算字段expression中作为唯一标识使用）,新数据跟uniqueId值相同 */
    name?: string;
    /** 引用表id */
    table: string;
    /** 物理字段 */
    column: string;
    /** 是否为衍生字段，分组字段和计算字段都为true */
    calculateMember: boolean;
    /** 字段描述，仅日期类型会使用 */
    comments?: string;
    attributes: FieldAttribute[];
}
/** 当前数据类型，如果没有进行过类型切换，则和OriginDataType一致 影响sql生成 (原colType) */
export declare enum DataType {
    number = "number",
    string = "string",
    date = "date",
    datetime = "datetime",
    time = "time"
}
/** 二级数据类型：不影响sql生成，影响内存处理及前端icon展示（如：地理维度、） */
export declare enum SecondDataType {
    number = "number",
    string = "string",
    geographic = "geographic",
    imageUrl = "imageUrl",
    date = "date",
    datetime = "datetime",
    time = "time"
}
/** 物理数据类型：第一次初始化时填写，后续不会修改 */
export declare type OriginDataType = DataType;
/** 日期维度支持的粒度 */
export declare enum DateGranularity {
    year = "year",
    quarter = "year-quarter",
    month = "year-month",
    week = "year-week",
    day = "year-month-day",
    hour = "hour",
    minute = "hour-minute",
    second = "hour-minute-second",
    datetime = "datetime"
}
/** 地理维度支持的粒度 */
export declare enum RegionGranularity {
    /** 洲 */
    continent = "CONTINENT",
    /** 国家 */
    country = "COUNTRY",
    /** 区域 */
    region = "REGION",
    /** 自定义区域 */
    custom_region = "CUSTOM_REGION",
    /** 省 */
    province = "PROVINCE",
    /** 市 */
    city = "CITY",
    /** 区 */
    xian = "XIAN",
    /** 经度 */
    lng = "LNG",
    /** 纬度 */
    lat = "LAT"
}
/**
 * 维度树结构类型
 * Normal: 正常层级结构
 * Date: 日期类型层级结构
 * Linked: 关联类型层级结构
 */
export declare type DimensionTreeFlags = 'DimensionNormal' | 'DimensionDate' | 'DimensionLinked' | null;
/**
 * 度量树结构类型
 * Normal: 正常层级结构
 * Linked: 关联类型层级结构
 */
export declare type MeasureTreeFlags = 'MeasureNormal' | 'MeasureLinked' | null;
/** 树节点类型 */
export declare type TreeNodeTypes = 'folder' | 'hierarchy' | 'attribute' | 'dimensionGroup' | 'measureGroup';
/** 分组字段类型 */
export declare type GroupType = 'NormalGroup' | 'ListGroup' | 'CustomizedGroup';
/** 数值-自定义分组类型 */
export declare type CustomizedGroup = {
    /** 是否是默认分组字段 */
    groupName: string;
    defaultGroup: boolean;
    lower: string;
    upper: string;
    lowerOperator: 'greaterThan' | 'greaterThanOrEqualTo';
    upperOperator: 'lessThan' | 'lessThanOrEqualTo';
    groupNameType: any;
};
/** 枚举-列表分组类型 */
export declare type ListGrouping = {
    groupName: string;
    groupElementList: string[];
    defaultGroup: boolean;
};
/** 日期类型-自定义区间分组 */
export declare type NormalGroup = {
    groupName: string;
    defaultGroup: boolean;
    lower: string;
    upper: string;
    lowerOperator: 'greaterThanOrEqualTo';
    upperOperator: 'lessThanOrEqualTo';
};
/** 分组字段 */
export declare type Groups = CustomizedGroup[] | ListGrouping[] | NormalGroup[];
/** 字段属性 */
export interface FieldAttribute {
    /** 唯一标识 */
    uniqueId: string;
    /** 显示名称 */
    caption: string;
    /** 标记数据面板上的字段、文件夹，和数据集原有的字段、文件夹区别开来 */
    fromPanel?: boolean;
    /** 老接口保留字段（计算字段expression中作为唯一标识使用）,新数据跟uniqueId值相同 */
    name?: string;
    /** 一级数据类型（分析类型）：影响sql生成 */
    dataType: DataType;
    /** 二级数据类型：不影响sql生成，影响内存处理及前端icon展示（如：地理维度、） */
    secondDataType: SecondDataType | null;
    /** 原始物理数据类型 */
    originDataType: OriginDataType | null;
    /** 格式化格式 */
    format: string | null;
    /** 表数据物理存储格式(暂未使用2021-03) */
    dataFormat: string | null;
    /** 维度、粒度 */
    granularity: DateGranularity | RegionGranularity | null;
    /** 自定义区域id */
    refCustomRegion?: string;
    /** 聚合方式 */
    aggregator: Aggregator | null;
    /** 是否支持做聚合, 维度=null, 普通度量/非聚合的扩展度量=true, 聚合扩展度量=false */
    supportAggregation: boolean | null;
    /** 自定义周的开始时间，只在周类型时间维度有效, 从 1-7 代表周一到周日 */
    firstDayOfWeek: number | null;
    /** 是否隐藏 */
    isHidden: boolean;
    /** 倍率 */
    mult: string | null;
    /** 计算字段、分组字段 */
    expression?: Expression;
    /** 字段描述 */
    comments?: string;
    /** 字段自定义排序设置 */
    sortModel?: {
        sortType: 'ASC' | 'DESC' | 'CUSTOM';
        customOrder: string;
        orderByList?: any;
    };
}
/** 度量类型聚合方式 */
export declare enum Aggregator {
    'sum' = "sum",
    'count' = "count",
    'distinct-count' = "distinct-count",
    'max' = "max",
    'min' = "min",
    'avg' = "avg"
}
export interface Expression {
    type: 'dataGroup' | 'udf';
    value?: string;
    /** 分组字段配置 */
    dataGroup: {
        /** 唯一标识 */
        uniqueId: string;
        /** 分组名称 */
        caption: string;
        /** 分组类型 */
        groupType: GroupType;
        refUniqueId: string;
        /** qa中使用。qbi目前用不到 */
        refSql?: string;
        /** qa中使用。qbi目前用不到 */
        refFunction?: string;
        /** 数值类型分组字段 */
        customizedGroups?: CustomizedGroup[];
        /** 字符串类型分组字段 */
        listGroupings?: ListGrouping[];
        /** 日期类型分组字段 */
        normalGroups?: NormalGroup[];
    };
}
export declare class FilterAttr {
    logicalOperator: 'and' | 'or';
    /** 过滤值 */
    filterElements: FilterElement[];
    /** 嵌套过滤条件 */
    filters: FilterAttr[];
}
export interface FilterElement {
    /** 过滤条件引用的字段uid */
    resourceId: string;
    /** 过滤条件比较运算符：> < =, 和查询控件所用保持一致 */
    functionalOperator: string;
    values: {
        type?: 'absolute' | 'relative' | null;
        value: string;
    }[];
    /** 前端是否隐藏掉 */
    hidden?: boolean;
}
/** 普通字段 */
export interface AttributeNode {
    /** 字段ID */
    id: string;
    /** 节点类型 */
    type: TreeNodeTypes;
    /** 标记数据面板上的字段、文件夹，和数据集原有的字段、文件夹区别开来 */
    fromPanel?: boolean;
    /** 节点名称,attribute类型为null */
    name?: null;
    caption?: string;
    children?: (AttributeNode | FolderAndHierarchyNode)[];
    flag: null;
    /** 所引用的关联表的id，仅flag为DimensionLinked和MeasureLinked时存在 */
    refUniqueId?: null;
}
/** 文件夹和层级字段 */
export interface FolderAndHierarchyNode {
    /** 字段ID */
    id?: string;
    /** 节点类型 */
    type: TreeNodeTypes;
    /** 标记数据面板上的字段、文件夹，和数据集原有的字段、文件夹区别开来 */
    fromPanel?: boolean;
    /** 节点名称 */
    name?: string;
    /** 节点名称,attribute类型为null */
    caption?: string;
    /** 所引用的关联表的id，仅flag为DimensionLinked和MeasureLinked时存在 */
    refUniqueId?: string;
    children?: (AttributeNode | FolderAndHierarchyNode)[];
    /** 文件夹和层级结构类型 */
    flag: DimensionTreeFlags | MeasureTreeFlags;
}
export interface ParamType {
    /** sql参数id */
    uniqueId?: string;
    /** 是否启用此参数 */
    /** 占位符名称 */
    name: string;
    /** 类型 */
    style: 'condition' | 'placeholder' | 'param';
    /** 占位符格式化类型 */
    type: ParamDataType;
    table: string;
    format: string;
    firstDayOfWeek: number;
    /** condition条件参数时，才会有该属性 */
    conditionPlaceHolderFields?: {
        uniqueId: string;
        name: string;
        column: string;
        table: string;
    }[];
    /** sql 占位符的原始类型 */
    originalType: 'dateRange';
    /** sql 参数，占位符默认值 */
    defaultValue?: (string | number)[];
    /** 默认值是否全局生效，true: 生效范围与过滤器一致。false: 默认值仅在数据集生效 */
    useInGlobal?: boolean;
}
/** 占位符参数 */
export declare enum ParamDataType {
    string = "string",
    number = "number",
    dateRegion = "dateRegion",
    monthRegion = "monthRegion",
    weekRegion = "weekRegion",
    yearRegion = "yearRegion",
    ymdHmsRegion = "ymdHmsRegion"
}
